import pickle as p
import sys
import numpy as np
from pylab import *
import os

def addAxes(ax, d, key1, key2, idx, title, colWid = 0.75):
    keyList = ['5785_1', '5785_2','5785_3','5785_4']
    # Get values at keys
    val = [d[k][key1][key2][0] for k in keyList]
    dval = [d[k][key1][key2][1] for k in keyList]

    # add bar plot to axes
    rect = ax.bar(idx, val, colWid, alpha = 0.5,ecolor = 'k', yerr = dval)

    # set tick labels 
    ax.set_xticks([i+colWid/2.0 for i in idx])
    ax.set_xticklabels( [1, 2, 3, 4], fontsize = 8)
    ax.set_title(title)
    ax.xaxis.tick_bottom()

# load database
data = p.load(open("../Data/Erythromycin.p",'rb'))

# Set plotting parameters
wid = 7.0
height = wid * (sqrt(5.0) -1.0) / 4.0 # golden ratio, might make shorter
parameters = {'backend': 'ps', 'axes.labelsize': 6,'text.fontsize': 8,'xtick.labelsize': 6,'ytick.labelsize': 6,'figure.figsize': [wid, height], 'legend.fontsize': 6, 'font.family':'sans-serif', 'font.sans-serif':'arial' }
legendsize = '5'
rcParams.update(parameters)

# Make figure
fig = figure(1)
# Make 4 indices 
idx = np.arange(4)
idx = [i+0.13 for i in idx]

# Add water solvation free energy
ax1 = fig.add_subplot(151)
addAxes(ax1, data, 'water','energy', idx,r'$\Delta G_{Hydration}$' )
ax1.yaxis.tick_left()
ax1.set_ylabel('energy (kJ/mol)', fontsize = 8)

# Add cyclohexane solvation free energy
ax2 = fig.add_subplot(152)
addAxes(ax2, data, 'cyclohexane','energy', idx, r'$\Delta G_{Cyclohexane}$')
ax2.yaxis.tick_left()

# Add octanol solvation free energy
ax3 = fig.add_subplot(153)
addAxes(ax3, data, 'octanol','energy', idx, r'$\Delta G_{Octanol}$')
ax3.yaxis.tick_left()

# Add logPcyc
ax4 = fig.add_subplot(154)
addAxes(ax4, data, 'cyclohexane','LogP_calc', idx, r'$\log P_{cyc}$')
ax4.yaxis.tick_right()

# Add logPoct
ax5 = fig.add_subplot(155)
addAxes(ax5, data, 'octanol','LogP_calc', idx, r'$\log P_{oct}$')
ax5.yaxis.tick_right()
ax5.set_ylabel(r'$\log P$', fontsize = 8)
ax5.yaxis.set_label_position('right')

xlabel = 'Initial conformation of erythromycin'
fig.text(0.5, 0.04, xlabel, ha='center')

fig.frameon = False
# Adjust subplots and save figure
subplots_adjust(left = 0.1, right = 0.90, bottom = 0.15, top = 0.85)
savefig('../../Paper/erythromycinBarPlot.pdf')
savefig('../../Paper/erythromycinBarPlot.eps')

