# Written by Caitlin C Bannan
# Adapted from extractResults.py to get results for four erythromycin simulations with different starting conformations
import numpy as np
import commands
import sys
import pickle as p
import os

database = p.load(open("../Data/dictionary_noResults.p","rb"))
for k, e in database.items():
    if e['number'] == '5785':
        erythro = k
resultsData = {}
Warning_Limit = 3
kB = 1.380648*6.02214129/1000.0
conv = 4.184
warnings = []
result_File = "../Data/%s/%s/results.pickle"
solvent_list = ['cyclohexane','water','octanol']

def getEnergy(fileName, Warning_Limit = 2.):
    warn = None
    if not os.path.isfile(fileName):
        split = fileName.split('/')
        print "\t file not found for", split[1], " in ", split[2], fileName
        warn = "File not found" 
        return None, None, warn

    getData = p.load(open(fileName, 'rb'))
    T = getData.temperature

    dF = getData.dFs[2]
    ddF = getData.ddFs[2]

    energies = np.array([e for (k, e) in dF.items()])
    uncertanties = np.array([e for (k, e) in ddF.items()])

    MBAR = np.array([dF['MBAR'], ddF['MBAR']])
        
    maxDif = max(energies) - min(energies)
    maxUn = max(uncertanties)
    tol = maxUn*Warning_Limit
    if (np.abs(maxDif) > (tol)) and (tol > 1):
        warn = "Warning energy difference (%.3f) is bigger than %s * the largest uncertainty (%.3f)" % (maxDif, str(Warning_Limit), maxUn)

    kJ = MBAR * kB * T
    return kJ[0],kJ[1],warn

ConDif = {'5785_2':{}, '5785_3':{}, '5785_4':{}}
ConDif['5785_1'] = database[erythro]

print "logPcyc exp, %.2f, logPoct, %.2f" % (ConDif['5785_1']['octanol']['LogP_exp'][0],ConDif['5785_1']['cyclohexane']['LogP_exp'][0]) 

print "number, dGwat, ddGwat, dGcyc, ddGcyc, dGoct, ddGoct, logPcyc, dlogPcyc, logPoct, dlogPoct"

for num, entry in ConDif.items():
    for solv in solvent_list:
        if not entry.has_key(solv):
            entry[solv] = {}
        En, Un, warn = getEnergy(result_File % (num, solv))
        if warn != None:
            warnings.append(warn + " %s in %s" % (num, solv))
            entry[solv]['warn'] = warn
        entry[solv]['energy'] = [En, Un]
           
    h2o_en = entry['water']['energy']
    for solv in ['cyclohexane','octanol']:
        solv_en = entry[solv]['energy']
        Dif = np.array([(solv_en[0] - h2o_en[0]), np.sqrt(h2o_en[1]**2 + solv_en[1]**2)])
        LogP = Dif/(np.log(10.)*kB*298.15)
        entry[solv]['LogP_calc'] = LogP
        perErrList = []
        exp_logP = ConDif['5785_1'][solv]['LogP_exp'][0]
        if exp_logP == 0.0:
            perErrList.append(0.0)
        else:
            perErrList.append(np.abs((LogP[0]-exp_logP)/exp_logP))
        entry[solv]['perError'] = perErrList
    
    print "%s, %.2f, %.2f, %.2f, %.2f, %.3f, %.3f, %.3f, %.3f, %.3f, %.3f" % (num, entry['water']['energy'][0], entry['water']['energy'][1], entry['cyclohexane']['energy'][0],entry['cyclohexane']['energy'][1], entry['octanol']['energy'][0], entry['octanol']['energy'][1], entry['cyclohexane']['LogP_calc'][0], entry['cyclohexane']['LogP_calc'][1], entry['octanol']['LogP_calc'][0], entry['octanol']['LogP_calc'][1]) 

p.dump(ConDif, open("../Data/Erythromycin.p", "wb"))
